// use arrow keys (left/right) or menu at bottom to browse through files
// space starts/stops playback
// jog shuttle below player adjusts playback speed
// drag and drop playback cursor
// zoom with mousewheel

import arb.soundcipher.*;

// synthesizer variables
SoundCipher sc = new SoundCipher(this);
// Variables for reading data from file
BufferedReader reader;
String line;
int lineNumber=0;

// There's a list of notes extracted from the file; each note has a noteNumber and the properties are:
int[] note        = new int[30000]; 
int[] duration    = new int[30000]; 
int[] instrument  = new int[30000]; 
int[] time        = new int[30000]; 


int[] noteOn      = new int[100];  // remembers last turned on note on keybd during parsing
int   maxNotes    = 0;             // amount of notes in file
int   noteNumber  = 0;             // used for counting during logic parsing

int[] instrumentNumber={1, 16, 10, 105};// 0:electric piano // 1:space synth // 2:glockenspiel // 3:cembalo

float pixelsPerMillis;             // pixels to millis proportions
float millisPerPixels;             // millis to pixels proportions
int   cursor;                      // mouseCursor in Millis
int   pCursor;                     // previous mouseCursor in Millis
boolean dragCursor=false;          // remembers if cursor is dragged by mouse
int playerW;                       // player window width
int playerX;                       // player window x-position

String date;                       // date of recording of currently loaded file
int startHour;                     // start time of recording of currently loaded file
int startMinute;
int startSecond;

boolean     play=false;            // toggles start/stop playback
int         lastMillis=0;          // saves the time when last loop was executed

String[]    fileName=new String[3000]; // fileselector stuff
String      currentFile="";
int         currentFileNumber=-1;
int[]       fileSize = new int[3000];     // size of each logfile in directory
String[]    fileTime = new String[3000];  // time and date of each logfile in directory
int         fileCount = 0;
int         selectTime = 0;        // used to slow down file selector with arrow key; stores millis

boolean     dragJog=false;         // currently dragging jog/shuttle
float       jogPosition =0;        // position of jogwheel (0...1)

float       zoom=0;  
boolean     pKeyPressed = false;
boolean     pMousePressed = false;

////////////////////////////////////////////////////////// * SETUP *  //////////////////////////////////////////


void setup() {
  size(1500, 900);

  surface.setResizable(true);
  String path = sketchPath()+"/data";                         // define input folder

  File[] files = listFiles(path);                             // count files in folder, remember their names
  for (int i = 0; i < files.length; i++) {
    File f = files[i];    
    String ftl=f.getName().substring(0, 3);
    if (ftl.equals("LOG")==true) {
      fileName[fileCount]=f.getName();
      fileSize[fileCount]=int(f.length());
      //  print(" >> File "+fileCount+": " + fileName[fileCount]+" Size: "+fileSize[fileCount]);
      fileCount++;
    }
  }

  ///////////////////           // get all times and dates of individual files

  for (int i=0; i<fileCount; i++) {
    reader = createReader(fileName[i]);
    lineNumber=0;
    boolean readingFile=true;
    while (readingFile) {
      try {
        line = reader.readLine();
      } 
      catch (IOException e) {
        e.printStackTrace();
        line = null;
      }
      if (line != null) {                                            // if line from file is available 
        lineNumber++;                                                // count new line
        if (lineNumber==1) {                                         // parse content of line 1 and get start time
          fileTime[i]=line;
        }
        if (lineNumber>1) {                                          // exit reading file after line 1
          readingFile=false;
        }
      } else {                                                       // if NO line from file is available 
        readingFile=false;                                           // exit reading file if no line is available
      }
    }
  }

  ///////////////////
}


////////////////////////////////////////////////////////// * DRAW *  //////////////////////////////////////////
void draw() {
  //...................................................................................... keyboard inputs
  if (keyPressed) {

    if (key==' ' && !pKeyPressed) {                                       // space: toggle playback
      play=!play;
    }
    if (keyCode==37 && selectTime<millis()) {                                // arrow left: select previous file 
      currentFileNumber=constrain(currentFileNumber-1, 0, fileCount-1);
      readFile(fileName[currentFileNumber]);
      selectTime=millis()+75;
    }
    if (keyCode==39 && selectTime<millis()) {                                // arrow left: select next file 
      currentFileNumber=constrain(currentFileNumber+1, 0, fileCount-1);
      readFile(fileName[currentFileNumber]);
      selectTime=millis()+75;
    }
  }

  pKeyPressed=keyPressed;
  //...................................................................................... zooming

  pixelsPerMillis=width-100;                                     // calculate screen to millis proportions
  pixelsPerMillis=pixelsPerMillis/600000*(zoom/2+1);
  millisPerPixels=1/pixelsPerMillis;
  playerW=width-100;
  float pxf=(50-cursor*pixelsPerMillis)+(float(cursor)/600000)*(width-100);
  playerX=int(pxf+.5);



  //...................................................................................... draw grid  
  background(0);

  drawTimeGrid();


  //...................................................................................... play button
  int xPlay=50;
  int yPlay=498;
  noStroke();

  boolean mouseOverPlay=false;
  if (mouseX>=xPlay && mouseX<=xPlay+100 &&mouseY>=yPlay && mouseY<=yPlay+20 && !dragCursor &&!dragJog) {
    mouseOverPlay=true;
  }

  fill(150, 0, 0);
  if (mouseOverPlay) {

    fill(255, 0, 0);
    if (mousePressed && !pMousePressed) {
      play=!play;
    }
  }

  if (play) {
    fill(0, 200, 0);
  }

  rect(xPlay, yPlay, 100, 20);                                                  // draw play button
  fill(0);
  beginShape();
  vertex(xPlay+45, yPlay+2);
  vertex(xPlay+60, yPlay+10);
  vertex(xPlay+45, yPlay+18);
  endShape(CLOSE);

  //...................................................................................... jog/shuttle
  int xJog=230;
  int yJog=498;
  int jogWidth=width-280;
  boolean mouseOverJog=false;
  if (mouseX>=xJog && mouseX<=xJog+jogWidth && mouseY>=yJog && mouseY<= yJog+20) {
    mouseOverJog=true;
  }

  if (mouseOverJog && mousePressed && !dragCursor) {
    dragJog=true;
  }
  if (!mousePressed) {
    dragJog=false;
  }

  if (dragJog) {                                        // update playback speed based on mouse dragging
    jogPosition=float(mouseX-xJog)/jogWidth;
  }
  jogPosition=constrain(jogPosition, 0, 1);             // constrain playback speed (=jog position)
  fill(32);



  if ((mouseOverJog && !dragCursor)) {
    fill(48);
  }     
  if (dragJog) {
    fill(32);
  } 
  noStroke();
  rect(xJog, yJog, jogWidth, 20);                                                  // draw jog box

  stroke(85);
  for (int i=1; i<20; i++) {                                                       // draw jog grid
    line(xJog+jogWidth/20*i, yJog+1, xJog+jogWidth/20*i, yJog+19);
  }

  stroke(0, 255, 0);                                                               // draw jog cursor
  line(xJog+jogPosition*jogWidth, yJog, xJog+jogPosition*jogWidth, yJog+20);

  fill(0, 255, 0);
  int xOffset=10;
  if (jogPosition>.90) {
    xOffset=-50;
  }
  text(nf(jogPosition*20+1, 0, 1)+"x", xJog+jogPosition*jogWidth+xOffset, yJog+16);


  fill(128);
  text("speed:", xJog-62, yJog+16);

  //...................................................................................... cursor dragging / mouseover logic
  float cursorInPixels=cursor*pixelsPerMillis;


  pCursor=cursor;                                                // remember previous cursor position

  int elapsedTime=millis()-lastMillis;                           // check how much time passed since last loop
  lastMillis=millis();
  if (play) {
    cursor+=((jogPosition)*20+1)*elapsedTime;                          // advance cursor if playing back
    if (cursor>=600000) {                                        // end of 10 minutes reached, stop playback
      play=false;
    }
  }

  if ( mouseY>25 && mouseY<510 && mousePressed && !dragJog) {    // move cursor based on clicking in timeline
    dragCursor=true;
  }
  if (!mousePressed) {
    dragCursor=false;
  }
  if (dragCursor) { 
    float fCursor=float(mouseX-playerX)*(1/pixelsPerMillis);     //update cursorposition in millis
    cursor=int(fCursor);
  }


  cursor=constrain(cursor, 0, 600000);                           // limit cursor 0...600seconds

  stroke(0, 200, 0);                                             // draw cursor
  line(cursorInPixels+playerX, 45, cursorInPixels+playerX, 475);
  drawAllNotes(pCursor, cursor );


  //...................................................................................... play sounds 



  for (int i=0; i<=maxNotes; i++) {                           // cycle through all notes
    if (time[i] >= cursor && time[i] < pCursor || time[i] <= cursor && time[i] > pCursor ) {
      sc.tempo(60);
      sc.instrument(instrumentNumber[instrument[i]]);
      if (!mousePressed) {                                      // dragging cursor?
        sc.playNote(note[i]+36, 100, float(duration[i])/512*((jogPosition)*20+1) );  // play note in last timeframe
      } else {
        sc.playNote(note[i]+36, 70, .1 );                       // play note silent and staccato in cursorframe
      }
    }
  }


  //...................................................................................... write time and date at cursor

  fill(0, 255, 0);
  textSize(16); 
  int xText=int(cursorInPixels+playerX);
  if (xText < width-200) {
    xText+=10;
    textAlign(LEFT);
  } else {
    xText-=165;
  }
  String dateS="date: ";
  if (date!=null) {
    dateS+=date;
  }
  int cursorHour=startHour;
  int cursorMinute=startMinute;
  int cursorSecond=startSecond;

  cursorSecond=((cursorSecond*1000+cursor)/1000)%60;
  cursorMinute=((cursorMinute*60000+cursor+startSecond*1000)/60000)%60;
  cursorHour=((cursorHour*3600000+cursor+startMinute*60000+startSecond*1000)/3600000)%24;

  String timeS="time: ";
  if (cursorHour<10) {
    timeS+="0";
  }
  timeS+=cursorHour+":";
  if (cursorMinute<10) {
    timeS+="0";
  }
  timeS+=cursorMinute+":";
  if (cursorSecond<10) {
    timeS+="0";
  }
  timeS+=cursorSecond;
  text(dateS, xText, 60);
  text(timeS, xText, 80);

  //...................................................................................... draw file selector
  noStroke();
  int x=50;
  int y=620;
  int mouseOverFile=-1;
  for (int i=0; i<fileCount; i++) {
    noStroke();
    fill(((i/6)%2+1)*32);                                                             // background color file item

    if (i==currentFileNumber) {                                                       // currently selected file
      stroke(0, 255, 0);
      fill(0);
    }

    if (mouseX>=x && mouseX<=x+6 && mouseY>=y-40 && mouseY<=y+10 && !dragCursor  && !dragJog) {    // mouseOver and not dragging cursor
      mouseOverFile=i;
      stroke(255);
      fill(0);
    }
    rect(x, y, 6, -40);                                                               // draw box background

    fill(128);    

    if (i==currentFileNumber) {                                                       // currently selected file
      stroke(0, 255, 0);
      fill(0, 255, 0);
    }
    if (mouseOverFile==i) {                                                           // mouseOver
      fill(255);
    }

    rect(x, y, 5, -constrain(sqrt(fileSize[i])/8, 0, 40));                            // draw filesize
    x+=7;
    if (x>=width-50) {
      x=50;
      y+=50;
    }
  }


  if (mouseOverFile>=0) {
    fill(0, 255, 0);
    text("file: "+fileName[mouseOverFile]+"  date/time: "+fileTime[mouseOverFile]+"  size: "+fileSize[mouseOverFile]+" KB", 50, 570);
    if (mousePressed && !pMousePressed) {  // ........................ open a new file
      readFile(fileName[mouseOverFile]);
      currentFile=fileName[mouseOverFile];
      currentFileNumber=mouseOverFile;
    }
  } else {
    fill(200);
    if (currentFileNumber>0) {
      text("file: "+fileName[currentFileNumber]+"  date/time: "+fileTime[currentFileNumber]+"  size: "+fileSize[currentFileNumber]+" KB", 50, 570);
    }
  }
  pMousePressed=mousePressed;
} 



////////////////////////////////////////////////////////// FUNCTIONS //////////////////////////////////////////


//-------------------------------------------------------------------------------------------------------- draw notes
void drawAllNotes(int highlightBegin, int highlightEnd) {
  noStroke();
  for (int i=1; i<=maxNotes; i++) {  

    boolean hit = false;                                                                                // hit detection (note currently starting to play)
    if (highlightEnd>=time[i] &&   highlightBegin<time[i]) {
      hit=true;
    }


    boolean highlighted=false;                                                                          // highlight detection (note currently playing)
    if (highlightEnd>=time[i] &&   highlightBegin<time[i]+duration[i]) {
      highlighted=true;
    }
    if (highlighted) {
      switch (instrument[i]) {
      case 0:
        fill(255, 0, 0);
        break;
      case 1:
        fill(0, 0, 255);
        break;
      case 2:
        fill(255, 0, 255);
        break;
      case 3:
        fill(255, 255, 0);
        break;
      }

      rect(time[i]*pixelsPerMillis-2+playerX, note[i]*10+98, duration[i]*pixelsPerMillis+5, 9);
    } else {
      switch (instrument[i]) {
      case 0:
        fill(255, 0, 0, 128);
        break;
      case 1:
        fill(0, 0, 255, 128);
        break;
      case 2:
        fill(255, 0, 255, 128);
        break;
      case 3:
        fill(255, 255, 0, 128);
        break;
      }
      rect(time[i]*pixelsPerMillis+playerX, note[i]*10+100, duration[i]*pixelsPerMillis+2, 6);
    }
    if (hit) {
      noFill();
      stroke(255);
      rect(time[i]*pixelsPerMillis-3+playerX, note[i]*10+96, duration[i]*pixelsPerMillis+8, 12);
      noStroke();
    }
  }
}
//--------------------------------------------------------------------------------------------------------
void drawTimeGrid() {
  for (int i=0; i<10; i++) {                            
    if (i%2==1) {
      fill(32);
    } else {
      fill(48);
    }
    noStroke();
    rect(i*60000*pixelsPerMillis+playerX, 90, 60000*pixelsPerMillis, 385);
  }

  if (zoom>=20) {
    // draw 1 second lines
    for (int i=0; i<600; i++) {                            
      stroke(0, 60);
      line(i*1000*pixelsPerMillis+playerX, 90, i*1000*pixelsPerMillis+playerX, 475);
    }
  }


  if (zoom>=10) {
    // draw 10 seconds lines
    for (int i=0; i<60; i++) {                            
      stroke(0, 128);
      line(i*10000*pixelsPerMillis+playerX, 90, i*10000*pixelsPerMillis+playerX, 475);
    }
  }

  // draw 30 seconds lines
  for (int i=0; i<20; i++) {                            
    stroke(0);
    line(i*30000*pixelsPerMillis+playerX, 90, i*30000*pixelsPerMillis+playerX, 510);
  }
}

//--------------------------------------------------------------------------------------------------------
void mouseWheel(MouseEvent event) {
  zoom -= 2*event.getCount();
  zoom=constrain(zoom, 0, 100);
  //  println(zoom);
}


// This function returns all the files in a directory as an array of Strings  
String[] listFileNames(String dir) {
  File file = new File(dir);
  if (file.isDirectory()) {
    String names[] = file.list();
    return names;
  } else {
    // If it's not a directory
    return null;
  }
}